==> cramr_ui_lib-0.0.15.tar.gz: lib/settings/settings_service.dart <==
import 'package:cramr_ui_lib/model/cardinality_selection.dart';
import 'package:flutter/material.dart';
import 'package:shared_preferences/shared_preferences.dart';

/// A service that stores and retrieves user settings.
///
/// By default, this class does not persist user settings. If you'd like to
/// persist the user settings locally, use the shared_preferences package. If
/// you'd like to store settings on a web server, use the http package.
class SettingsService {
  final SharedPreferences _prefs;

  SettingsService(this._prefs);

  /// Loads the User's preferred ThemeMode from local or remote storage.
  Future<ThemeMode> themeMode() async {
    var themeModeIndex = _prefs.getInt("themeMode");
    Future<ThemeMode> future = Future<ThemeMode>(() {
      ThemeMode result = ThemeMode.system;
      if (themeModeIndex == 1) {
        result = ThemeMode.light;
      } else if (themeModeIndex == 2) {
        result = ThemeMode.dark;
      }
      return result;
    });
    return future;
  }

  /// Persists the user's preferred ThemeMode to local or remote storage.
  Future<void> updateThemeMode(ThemeMode theme) async {
    // Use the shared_preferences package to persist settings locally or the
    // http package to persist settings over the network.
    _prefs.setInt("themeMode", theme.index);
  }

  Future<void> updateCardinalitySelection(
      CardinalitySelection selection) async {
    // Use the shared_preferences package to persist settings locally or the
    // http package to persist settings over the network.
    _prefs.setBool("cardinality.singularEnabled", selection.singularEnabled);
    _prefs.setBool("cardinality.pluralEnabled", selection.pluralEnabled);
  }

  Future<CardinalitySelection> cardinalitySelection() async {
    Future<CardinalitySelection> future = Future<CardinalitySelection>(() {
      bool? singular = _prefs.getBool("cardinality.singularEnabled");
      bool? plural = _prefs.getBool("cardinality.pluralEnabled");
      CardinalitySelection selection =
          CardinalitySelection(singular ?? true, plural ?? true);
      return selection;
    });
    return future;
  }
}

==> cramr_ui_lib-1.0.7.tar.gz: lib/settings/settings_service.dart <==
import 'package:cramr_ui_lib/model/cardinality_selection.dart';
import 'package:flutter/material.dart';
import 'package:shared_preferences/shared_preferences.dart';

/// A service that stores and retrieves user settings.
///
/// By default, this class does not persist user settings. If you'd like to
/// persist the user settings locally, use the shared_preferences package. If
/// you'd like to store settings on a web server, use the http package.
class SettingsService {
  final SharedPreferences _prefs;

  SettingsService(this._prefs);

  /// Loads the User's preferred ThemeMode from local or remote storage.
  ThemeMode themeMode() {
    var themeModeIndex = _prefs.getInt("themeMode") ?? 0;
    ThemeMode result = ThemeMode.system;
    if (themeModeIndex == 1) {
      result = ThemeMode.light;
    } else if (themeModeIndex == 2) {
      result = ThemeMode.dark;
    }
    return result;
  }

  /// Persists the user's preferred ThemeMode to local or remote storage.
  Future<void> updateThemeMode(ThemeMode theme) async {
    // Use the shared_preferences package to persist settings locally or the
    // http package to persist settings over the network.
    _prefs.setInt("themeMode", theme.index);
  }

  Future<void> updateCardinalitySelection(
      CardinalitySelection selection) async {
    // Use the shared_preferences package to persist settings locally or the
    // http package to persist settings over the network.
    _prefs.setBool("cardinality.singularEnabled", selection.singularEnabled);
    _prefs.setBool("cardinality.pluralEnabled", selection.pluralEnabled);
  }

  Future<CardinalitySelection> cardinalitySelection() async {
    Future<CardinalitySelection> future = Future<CardinalitySelection>(() {
      bool? singular = _prefs.getBool("cardinality.singularEnabled");
      bool? plural = _prefs.getBool("cardinality.pluralEnabled");
      CardinalitySelection selection =
          CardinalitySelection(singular ?? true, plural ?? true);
      return selection;
    });
    return future;
  }
}
